@@ -1,8 +1,3 @@
-/**
- * History:
- * - 2018.03.09 file created, following a restructuring of the previous library.
- */
-
 #ifndef UU_NET_IO_READCOMMON_H_
 #define UU_NET_IO_READCOMMON_H_
 
@@ -15,6 +10,7 @@
 #include "core/objects/Object.hpp"
 #include "objects/Vertex.hpp"
 #include "objects/Edge.hpp"
+#include "networks/Network.hpp"
 #include "io/_impl/GraphMetadata.hpp"
 #include "io/_impl/GraphIOFileSection.hpp"
 
@@ -118,20 +114,18 @@ read_edge(
     size_t line_number
 );
 
-template <typename G>
 void
 read_vertex(
-    G* g,
+    Network* g,
     const std::vector<std::string>& fields,
     const std::vector<core::Attribute>& vertex_attributes,
     size_t line_number
 );
 
 
-template <typename G>
 void
 read_edge(
-    G* g,
+    Network* g,
     const std::vector<std::string>& fields,
     const std::vector<core::Attribute>& edge_attributes,
     size_t line_number
@@ -302,38 +296,6 @@ read_edge(
     return edge;
 }
 
-template <typename G>
-void
-read_vertex(
-    G* g,
-    const std::vector<std::string>& fields,
-    const std::vector<core::Attribute>& vertex_attributes,
-    size_t line_number
-)
-{
-    (void)g; // attribute not used
-    (void)fields; // attribute not used
-    (void)vertex_attributes; // attribute not used
-    (void)line_number; // attribute not used
-    throw core::OperationNotSupportedException("Graph type not supported (IO)");
-}
-
-
-template <typename G>
-void
-read_edge(
-    G* g,
-    const std::vector<std::string>& fields,
-    const std::vector<core::Attribute>& edge_attributes,
-    size_t line_number
-)
-{
-    (void)g; // attribute not used
-    (void)fields; // attribute not used
-    (void)edge_attributes; // attribute not used
-    (void)line_number; // attribute not used
-    throw core::OperationNotSupportedException("Graph type not supported (IO)");
-}
 
 
 /* This function assumes that all the attribute values are present. */
